@@ -159,7 +159,6 @@ class Client(object):
                 #debug('greenlet %s completed, sending %s as response', gr, rv)
                 reply_fn(rv)
             except Exception as e:
-                self.error_cb(e)
                 if self.loop_running:
                     err_str = format_exc(5)
                     pass # replaces next logging statement
@@ -188,7 +187,6 @@ class Client(object):
                 pass # replaces next logging statement
                 #debug('greenlet %s completed', gr)
             except Exception as e:
-                self.error_cb(e)
                 if self.loop_running:
                     err_str = format_exc(5)
                     pass # replaces next logging statement
@@ -214,7 +212,7 @@ class Client(object):
 
 
     def loop_start(self, request_cb, notification_cb, error_cb):
-        profiling = 'NEOVIM_PYTHON_PROFILE' in os.environ
+        profiling = 'NVIM_PYTHON_PROFILE' in os.environ
 
         try:
             assert not self.loop_running
