@@ -23,16 +23,20 @@ class MsgpackStream(object):
 
             while True:
                 try:
-                    debug('waiting for message...')
+                    pass # replaces next logging statement
+                    #debug('waiting for message...')
                     msg = self.unpacker.next()
-                    debug('received message: %s', msg)
+                    pass # replaces next logging statement
+                    #debug('received message: %s', msg)
                     msg_cb(msg)
                 except StopIteration:
-                    debug('unpacker needs more data...')
+                    pass # replaces next logging statement
+                    #debug('unpacker needs more data...')
                     break
 
         self.stream.loop_start(data_cb, error_cb)
-        debug('exiting msgpack stream loop')
+        pass # replaces next logging statement
+        #debug('exiting msgpack stream loop')
 
 
     def loop_stop(self):
