@@ -165,10 +165,7 @@ class PluginHost(object):
 
         pass # replaces next logging statement
         #debug("running method handler for '%s %s'", name, args)
-        if args:
-            rv = handler(args)
-        else:
-            rv = handler()
+        rv = handler(*args)
         pass # replaces next logging statement
         #debug("method handler for '%s %s' returns: %s", name, args, rv)
         return rv
@@ -184,7 +181,7 @@ class PluginHost(object):
         pass # replaces next logging statement
         #debug('running event handlers for %s', name)
         for handler in handlers:
-            handler(args)
+            handler(*args)
 
 
     def on_error(self, err):
