@@ -11,7 +11,8 @@ class UvStream(object):
     Stream abstraction implemented on top of libuv
     """
     def __init__(self, address=None, port=None, spawn_argv=None):
-        debug('initializing UvStream instance')
+        pass # replaces next logging statement
+        #debug('initializing UvStream instance')
         self._loop = pyuv.Loop()
         self._error = None
         self._connected = False
@@ -36,21 +37,24 @@ class UvStream(object):
 
     def init_tcp(self, address, port):
         # tcp/ip
-        debug('TCP address was provided, connecting...')
+        pass # replaces next logging statement
+        #debug('TCP address was provided, connecting...')
         self._stream = pyuv.TCP(self._loop)
         self._stream.connect((address, port), self._on_connect)
 
 
     def init_pipe(self, address):
         # named pipe or unix socket
-        debug('Pipe address was provided, connecting...')
+        pass # replaces next logging statement
+        #debug('Pipe address was provided, connecting...')
         self._stream = pyuv.Pipe(self._loop)
         self._stream.connect(address, self._on_connect)
 
 
     def init_stdio(self):
         # stdin/stdout
-        debug('No addresses were provided, will use stdin/stdout')
+        pass # replaces next logging statement
+        #debug('No addresses were provided, will use stdin/stdout')
         self._read_stream = pyuv.Pipe(self._loop) 
         self._read_stream.open(sys.stdin.fileno())
         self._write_stream = pyuv.Pipe(self._loop) 
@@ -85,7 +89,8 @@ class UvStream(object):
         if error:
             msg = pyuv.errno.strerror(error)
             self._error = msg
-            warn('error connecting to neovim: %s', msg)
+            pass # replaces next logging statement
+            #warn('error connecting to neovim: %s', msg)
             self._connection_error = IOError(msg)
             return
         self._connected = True
@@ -123,7 +128,8 @@ class UvStream(object):
     def _on_stderr_read(self, handle, data, error):
         if error or not data:
             msg = pyuv.errno.strerror(error)
-            warn('Error reading child nvim stderr: %s', msg)
+            pass # replaces next logging statement
+            #warn('Error reading child nvim stderr: %s', msg)
             err = IOError(msg)
             if not self._error_cb:
                 self._loop.stop()
@@ -131,7 +137,8 @@ class UvStream(object):
                 raise err
             self._error_cb(err)
         else:
-            warn('nvim stderr: %s', data)
+            pass # replaces next logging statement
+            #warn('nvim stderr: %s', data)
 
 
     def _on_read(self, handle, data, error):
@@ -140,17 +147,20 @@ class UvStream(object):
         """
         if error:
             msg = pyuv.errno.strerror(error)
-            warn('error reading data: %s', msg)
+            pass # replaces next logging statement
+            #warn('error reading data: %s', msg)
             self._error_cb(IOError(msg))
             self._loop.stop()
             self._error = msg
         elif not data:
-            warn('connection was closed by neovim')
+            pass # replaces next logging statement
+            #warn('connection was closed by neovim')
             self._loop.stop()
             self._error = 'EOF'
             self._error_cb(IOError(self._error))
         else:
-            debug('successfully read %d bytes of data', len(data))
+            pass # replaces next logging statement
+            #debug('successfully read %d bytes of data', len(data))
             self._data_cb(data)
 
 
@@ -177,11 +187,14 @@ class UvStream(object):
                 self._loop.stop()
                 msg = pyuv.errno.strerror(error)
                 self._error = msg
-                warn('error writing data: %s', msg)
+                pass # replaces next logging statement
+                #warn('error writing data: %s', msg)
                 self._error_cb(IOError(msg))
-            debug('successfully wrote %d bytes of data', data_len)
+            pass # replaces next logging statement
+            #debug('successfully wrote %d bytes of data', data_len)
 
-        debug('writing %d bytes of data', data_len)
+        pass # replaces next logging statement
+        #debug('writing %d bytes of data', data_len)
         # queue the data for writing
         self._write_stream.write(data, write_cb)
 
@@ -202,9 +215,11 @@ class UvStream(object):
         self._read_stream.start_read(self._on_read)
         if self._error_stream:
             self._error_stream.start_read(self._on_stderr_read)
-        debug('entering libuv event loop')
+        pass # replaces next logging statement
+        #debug('entering libuv event loop')
         self._loop.run(pyuv.UV_RUN_DEFAULT)
-        debug('exited libuv event loop')
+        pass # replaces next logging statement
+        #debug('exited libuv event loop')
         if self._error_stream:
             self._error_stream.stop_read()
         self._read_stream.stop_read()
@@ -217,4 +232,5 @@ class UvStream(object):
         Stops the event loop
         """
         self._loop.stop()
-        debug('stopped event loop')
+        pass # replaces next logging statement
+        #debug('stopped event loop')
